package ejb.project;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import org.jboss.ejb3.embedded.EJB3StandaloneBootstrap;

/**
 * A superclass that our test classes can extend. This class simply provides some convienence methods that our
 * tests can use.
 *
 * @author  <a href="mailto:mazz@jboss.com">John Mazzitelli</a>
 */
public abstract class AbstractTestClass
{
   /**
    * Creates a Java Persistence entity manager factory. Subclasses usually won't need to call this - instead, see
    * {@link #createEntityManager()}.
    *
    * @return the entity manager factory
    */
   protected EntityManagerFactory createEntityManagerFactory()
   {
      return Persistence.createEntityManagerFactory( "ejb-project" );
   }

   /**
    * Creates a Java Persistence Entity Manager.
    *
    * @return the entity manager
    */
   protected EntityManager createEntityManager()
   {
      return createEntityManagerFactory().createEntityManager();
   }

   /**
    * Starts the Embedded EJB3 container so our tests can run in it.
    *
    * @see #shutdownEmbeddedEJB3()
    */
   protected static void startupEmbeddedEJB3()
   {
      EJB3StandaloneBootstrap.boot( null );
      EJB3StandaloneBootstrap.deployXmlResource( "embedded-ejb3-project-ds-beans.xml" );
      EJB3StandaloneBootstrap.scanClasspath();
   }

   /**
    * Stops the Embedded EJB3 container.
    *
    * @see #startupEmbeddedEJB3()
    */
   protected static void shutdownEmbeddedEJB3()
   {
      EJB3StandaloneBootstrap.shutdown();
   }
}
